@@ -3,23 +3,24 @@ package middleware
 import (
 	"encoding/base64"
 	"net/http"
+	"net/http/httptest"
+	"strings"
 	"testing"
 
 	"github.com/labstack/echo"
-	"github.com/labstack/echo/test"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestBasicAuth(t *testing.T) {
 	e := echo.New()
-	req := test.NewRequest(echo.GET, "/", nil)
-	res := test.NewResponseRecorder()
+	req := httptest.NewRequest(echo.GET, "/", nil)
+	res := httptest.NewRecorder()
 	c := e.NewContext(req, res)
-	f := func(u, p string) bool {
+	f := func(u, p string, c echo.Context) (bool, error) {
 		if u == "joe" && p == "secret" {
-			return true
+			return true, nil
 		}
-		return false
+		return false, nil
 	}
 	h := BasicAuth(f)(func(c echo.Context) error {
 		return c.String(http.StatusOK, "test")
@@ -27,24 +28,29 @@ func TestBasicAuth(t *testing.T) {
 
 	// Valid credentials
 	auth := basic + " " + base64.StdEncoding.EncodeToString([]byte("joe:secret"))
-	req.Header().Set(echo.HeaderAuthorization, auth)
+	req.Header.Set(echo.HeaderAuthorization, auth)
 	assert.NoError(t, h(c))
 
-	// Incorrect password
-	auth = basic + " " + base64.StdEncoding.EncodeToString([]byte("joe:password"))
-	req.Header().Set(echo.HeaderAuthorization, auth)
+	// Case-insensitive header scheme
+	auth = strings.ToUpper(basic) + " " + base64.StdEncoding.EncodeToString([]byte("joe:secret"))
+	req.Header.Set(echo.HeaderAuthorization, auth)
+	assert.NoError(t, h(c))
+
+	// Invalid credentials
+	auth = basic + " " + base64.StdEncoding.EncodeToString([]byte("joe:invalid-password"))
+	req.Header.Set(echo.HeaderAuthorization, auth)
 	he := h(c).(*echo.HTTPError)
 	assert.Equal(t, http.StatusUnauthorized, he.Code)
 	assert.Equal(t, basic+" realm=Restricted", res.Header().Get(echo.HeaderWWWAuthenticate))
 
-	// Empty Authorization header
-	req.Header().Set(echo.HeaderAuthorization, "")
+	// Missing Authorization header
+	req.Header.Del(echo.HeaderAuthorization)
 	he = h(c).(*echo.HTTPError)
 	assert.Equal(t, http.StatusUnauthorized, he.Code)
 
 	// Invalid Authorization header
 	auth = base64.StdEncoding.EncodeToString([]byte("invalid"))
-	req.Header().Set(echo.HeaderAuthorization, auth)
+	req.Header.Set(echo.HeaderAuthorization, auth)
 	he = h(c).(*echo.HTTPError)
 	assert.Equal(t, http.StatusUnauthorized, he.Code)
 }
