@@ -4,21 +4,21 @@ import (
 	"bytes"
 	"io/ioutil"
 	"net/http"
+	"net/http/httptest"
 	"testing"
 
 	"github.com/labstack/echo"
-	"github.com/labstack/echo/test"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestBodyLimit(t *testing.T) {
 	e := echo.New()
 	hw := []byte("Hello, World!")
-	req := test.NewRequest(echo.POST, "/", bytes.NewReader(hw))
-	rec := test.NewResponseRecorder()
+	req := httptest.NewRequest(echo.POST, "/", bytes.NewReader(hw))
+	rec := httptest.NewRecorder()
 	c := e.NewContext(req, rec)
 	h := func(c echo.Context) error {
-		body, err := ioutil.ReadAll(c.Request().Body())
+		body, err := ioutil.ReadAll(c.Request().Body)
 		if err != nil {
 			return err
 		}
@@ -27,7 +27,7 @@ func TestBodyLimit(t *testing.T) {
 
 	// Based on content length (within limit)
 	if assert.NoError(t, BodyLimit("2M")(h)(c)) {
-		assert.Equal(t, http.StatusOK, rec.Status())
+		assert.Equal(t, http.StatusOK, rec.Code)
 		assert.Equal(t, hw, rec.Body.Bytes())
 	}
 
@@ -36,17 +36,17 @@ func TestBodyLimit(t *testing.T) {
 	assert.Equal(t, http.StatusRequestEntityTooLarge, he.Code)
 
 	// Based on content read (within limit)
-	req = test.NewRequest(echo.POST, "/", bytes.NewReader(hw))
-	rec = test.NewResponseRecorder()
+	req = httptest.NewRequest(echo.POST, "/", bytes.NewReader(hw))
+	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	if assert.NoError(t, BodyLimit("2M")(h)(c)) {
-		assert.Equal(t, http.StatusOK, rec.Status())
+		assert.Equal(t, http.StatusOK, rec.Code)
 		assert.Equal(t, "Hello, World!", rec.Body.String())
 	}
 
 	// Based on content read (overlimit)
-	req = test.NewRequest(echo.POST, "/", bytes.NewReader(hw))
-	rec = test.NewResponseRecorder()
+	req = httptest.NewRequest(echo.POST, "/", bytes.NewReader(hw))
+	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	he = BodyLimit("2B")(h)(c).(*echo.HTTPError)
 	assert.Equal(t, http.StatusRequestEntityTooLarge, he.Code)
